@@ -1,15 +1,16 @@
-#This file is part of Tryton.  The COPYRIGHT file at the top level of
-#this repository contains the full copyright notices and license terms.
+# This file is part of Tryton.  The COPYRIGHT file at the top level of
+# this repository contains the full copyright notices and license terms.
 from decimal import Decimal
 from functools import partial
 
 from trytond.model import ModelView, fields
 from trytond.wizard import Wizard, StateView, StateTransition, Button
-from trytond.pyson import Eval, Get
+from trytond.pyson import Eval
 from trytond.transaction import Transaction
 from trytond.pool import Pool, PoolMeta
 
 from trytond.modules.account_product import MissingFunction
+from trytond.modules.product import price_digits
 
 __all__ = ['Category', 'Template', 'UpdateCostPriceAsk',
     'UpdateCostPriceShowMove', 'UpdateCostPrice']
@@ -190,14 +191,15 @@ class UpdateCostPriceAsk(ModelView):
         states={
             'invisible': ~Eval('product'),
             })
-    cost_price = fields.Numeric('Cost Price', required=True, digits=(16, 4))
+    cost_price = fields.Numeric('Cost Price', required=True,
+        digits=price_digits)
 
 
 class UpdateCostPriceShowMove(ModelView):
     'Update Cost Price Show Move'
     __name__ = 'product.update_cost_price.show_move'
     price_difference = fields.Numeric('Price Difference', readonly=True,
-        digits=(16, 4))
+        digits=price_digits)
     amount = fields.Numeric('Amount', readonly=True,
         digits=(16, Eval('currency_digits', 2)), depends=['currency_digits'])
     currency_digits = fields.Integer('Currency Digits', readonly=True)
@@ -221,13 +223,13 @@ class UpdateCostPrice(Wizard):
     ask_price = StateView('product.update_cost_price.ask',
         'account_stock_continental.update_cost_price_ask_form', [
             Button('Cancel', 'end', 'tryton-cancel'),
-            Button('Ok', 'should_show_move', 'tryton-go-next', default=True),
+            Button('OK', 'should_show_move', 'tryton-go-next', default=True),
             ])
     should_show_move = StateTransition()
     show_move = StateView('product.update_cost_price.show_move',
         'account_stock_continental.update_cost_price_show_move_form', [
             Button('Cancel', 'end', 'tryton-cancel'),
-            Button('Ok', 'create_move', 'tryton-ok', default=True),
+            Button('OK', 'create_move', 'tryton-ok', default=True),
             ])
     create_move = StateTransition()
     update_price = StateTransition()
@@ -236,8 +238,8 @@ class UpdateCostPrice(Wizard):
     def __setup__(cls):
         super(UpdateCostPrice, cls).__setup__()
         cls._error_messages.update({
-                'same_account': 'The stock account and the counterpart can '
-                    'not be the same account',
+                'same_account': ('The stock account and the counterpart can '
+                    'not be the same account'),
                 })
 
     def default_ask_price(self, fields):
